@@ -1,6 +1,6 @@
 /*****************************************************************************
  * Free42 -- an HP-42S calculator simulator
- * Copyright (C) 2004-2025  Thomas Okken
+ * Copyright (C) 2004-2026  Thomas Okken
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2,
@@ -45,7 +45,6 @@
 #define p_isinf(x) (isinf(x) ? (x) > 0 ? 1 : -1 : 0)
 #define p_isnan isnan
 #define p_isnormal isnormal
-#define p_sincos(x, s, c) { *(s) = sin(x); *(c) = cos(x); }
 #define to_digit(x) ((int) fmod((x), 10.0))
 #define to_char(x) ((char) (x))
 #define to_int(x) ((int) (x))
@@ -54,6 +53,12 @@
 #define to_uint8(x) ((uint8) (x))
 #define to_double(x) ((double) (x))
 
+#ifdef HAVE_SINCOS
+#define p_sincos sincos
+#else
+#define p_sincos(x, s, c) { *(s) = sin(x); *(c) = cos(x); }
+#endif
+
 #define PI 3.1415926535897932384626433
 #define P 7
 
@@ -154,6 +159,7 @@ Phloat fabs(Phloat p);
 Phloat pow(Phloat x, Phloat y);
 Phloat floor(Phloat x);
 Phloat fma(Phloat x, Phloat y, Phloat z);
+Phloat nextafter(Phloat x, Phloat y);
 int ilogb(Phloat x);
 Phloat scalbn(Phloat x, int y);
 Phloat copysign(Phloat x, Phloat y);
